@@ -6,6 +6,20 @@
 #include "evilwm.h"
 #include "log.h"
 
+static void current_to_head(void) {
+	Client *c;
+	if (current && current != head_client) {
+		for (c = head_client; c; c = c->next) {
+			if (c->next == current) {
+				c->next = current->next;
+				current->next = head_client;
+				head_client = current;
+				break;
+			}
+		}
+	}
+}
+
 static void handle_key_event(XKeyEvent *e) {
 	Client *c = find_client(e->window);
 	KeySym key = XKeycodeToKeysym(dpy,e->keycode,0);
@@ -13,18 +27,40 @@ static void handle_key_event(XKeyEvent *e) {
 	if (!c)
 		c = current;
 	if (c) {
+		int width_inc = (c->width_inc > 1) ? c->width_inc : 16;
+		int height_inc = (c->height_inc > 1) ? c->height_inc : 16;
 		switch (key) {
 		case KEY_LEFT:
-			c->x -= 16;
+			if (e->state & altmask) {
+				if ((c->width - width_inc) >= c->min_width)
+					c->width -= width_inc;
+			} else {
+				c->x -= 16;
+			}
 			goto move_client;
 		case KEY_DOWN:
-			c->y += 16;
+			if (e->state & altmask) {
+				if (!c->max_height || (c->height + height_inc) <= c->max_height)
+					c->height += height_inc;
+			} else {
+				c->y += 16;
+			}
 			goto move_client;
 		case KEY_UP:
-			c->y -= 16;
+			if (e->state & altmask) {
+				if ((c->height - height_inc) >= c->min_height)
+					c->height -= height_inc;
+			} else {
+				c->y -= 16;
+			}
 			goto move_client;
 		case KEY_RIGHT:
-			c->x += 16;
+			if (e->state & altmask) {
+				if (!c->max_width || (c->width + width_inc) <= c->max_width)
+					c->width += width_inc;
+			} else {
+				c->x += 16;
+			}
 			goto move_client;
 		case KEY_TOPLEFT:
 			c->x = c->border;
@@ -47,7 +83,7 @@ static void handle_key_event(XKeyEvent *e) {
 				- c->height-c->border;
 			goto move_client;
 		case KEY_KILL:
-			send_wm_delete(c, e->state & ShiftMask);
+			send_wm_delete(c, e->state & altmask);
 			break;
 		case KEY_LOWER: case KEY_ALTLOWER:
 			XLowerWindow(dpy, c->parent);
@@ -74,6 +110,16 @@ static void handle_key_event(XKeyEvent *e) {
 			break;
 		case KEY_NEXT:
 			next();
+			if (XGrabKeyboard(dpy, e->root, False, GrabModeAsync, GrabModeAsync, CurrentTime) == GrabSuccess) {
+				XEvent ev;
+				do {
+					XMaskEvent(dpy, KeyPressMask|KeyReleaseMask, &ev);
+					if (ev.type == KeyPress && XKeycodeToKeysym(dpy,ev.xkey.keycode,0) == KEY_NEXT)
+						next();
+				} while (ev.type == KeyPress || XKeycodeToKeysym(dpy,ev.xkey.keycode,0) == KEY_NEXT);
+				XUngrabKeyboard(dpy, CurrentTime);
+			}
+			current_to_head();
 			break;
 #ifdef VWM
 		case XK_1: case XK_2: case XK_3: case XK_4:
@@ -140,9 +186,10 @@ static void handle_configure_request(XConfigureRequestEvent *e) {
 
 		wc.x = c->x - c->border;
 		wc.y = c->y - c->border;
-		wc.border_width = 0;
+		wc.border_width = c->border;
 		XConfigureWindow(dpy, c->parent, e->value_mask, &wc);
 		send_config(c);
+		wc.border_width = 0;
 	}
 
 	wc.x = c ? 0 : e->x;
@@ -217,6 +264,7 @@ static void handle_enter_event(XCrossingEvent *e) {
 			return;
 #endif
 		select_client(c);
+		current_to_head();
 #ifdef MOUSE
 		grab_button(c->parent, grabmask2, AnyButton);
 #endif
