@@ -47,6 +47,7 @@ typedef struct {
 /* readability stuff */
 
 #define KEY_TO_VDESK(key) ((key) - XK_1)
+#define valid_vdesk(v) ((unsigned)(v) < KEY_TO_VDESK(XK_8))
 
 #define RAISE           1
 #define NO_RAISE        0       /* for unhide() */
@@ -60,18 +61,6 @@ typedef struct {
 #define grab_pointer(w, mask, curs) \
 	(XGrabPointer(dpy, w, False, mask, GrabModeAsync, GrabModeAsync, \
 	None, curs, CurrentTime) == GrabSuccess)
-#define grab_keysym(w, mask, keysym) \
-	XGrabKey(dpy, XKeysymToKeycode(dpy, keysym), (mask), w, True, \
-	         GrabModeAsync, GrabModeAsync); \
-	XGrabKey(dpy, XKeysymToKeycode(dpy, keysym), LockMask|(mask), w, True, \
-	         GrabModeAsync, GrabModeAsync); \
-	if (numlockmask) { \
-		XGrabKey(dpy, XKeysymToKeycode(dpy, keysym), numlockmask|(mask), \
-		         w, True, GrabModeAsync, GrabModeAsync); \
-		XGrabKey(dpy, XKeysymToKeycode(dpy, keysym), \
-		         numlockmask|LockMask|(mask), w, True, \
-		         GrabModeAsync, GrabModeAsync); \
-	}
 #define grab_button(w, mask, button) \
 	XGrabButton(dpy, button, (mask), w, False, ButtonMask, \
 	            GrabModeAsync, GrabModeSync, None, None); \
@@ -107,7 +96,6 @@ typedef struct ScreenInfo ScreenInfo;
 struct ScreenInfo {
 	int screen;
 	Window root;
-	Colormap def_cmap;
 	GC invert_gc;
 #ifdef VWM
 	XColor fg, bg, fc;
@@ -177,11 +165,6 @@ extern volatile Window  initialising;
 extern XFontStruct      *font;
 extern Client           *head_client;
 extern Application      *head_app;
-extern Atom             xa_wm_state;
-extern Atom             xa_wm_change_state;
-extern Atom             xa_wm_protos;
-extern Atom             xa_wm_delete;
-extern Atom             xa_wm_cmapwins;
 extern Cursor           move_curs;
 extern Cursor           resize_curs;
 extern const char       *opt_display;
@@ -197,12 +180,29 @@ extern int              vdesk;
 #ifdef SNAP
 extern int              opt_snap;
 #endif
+#ifdef SOLIDDRAG
+extern int              solid_drag;
+#else
+# define solid_drag (0)
+#endif
 #ifdef SHAPE
 extern int              have_shape, shape_event;
 #endif
-extern Atom             mwm_hints;
 extern unsigned int numlockmask;
 extern unsigned int grabmask2;
+extern unsigned int altmask;
+
+/* Standard X protocol atoms */
+extern Atom             xa_wm_state;
+extern Atom             xa_wm_protos;
+extern Atom             xa_wm_delete;
+extern Atom             xa_wm_cmapwins;
+/* Motif atoms */
+extern Atom             mwm_hints;
+/* EWMH atoms */
+extern Atom xa_net_wm_desktop;
+extern Atom xa_net_wm_state;
+extern Atom xa_net_wm_state_sticky;
 
 /* client.c */
 
@@ -233,13 +233,10 @@ void scan_windows(void);
 
 extern int need_client_tidy;
 extern int ignore_xerror;
-/* void do_event_loop(void); */
 int handle_xerror(Display *dsply, XErrorEvent *e);
 void spawn(const char *const cmd[]);
 void handle_signal(int signo);
-#ifdef DEBUG
-void show_event(XEvent e);
-#endif
+void grab_keysym(Window w, unsigned int mask, KeySym keysym);
 
 /* new.c */
 
@@ -262,3 +259,10 @@ void hide(Client *c);
 void switch_vdesk(int v);
 #endif /* def VWM */
 ScreenInfo *find_screen(Window root);
+
+/* ewmh.c */
+
+#ifdef VWM
+void update_net_wm_desktop(Client *c);
+void update_net_wm_state(Client *c);
+#endif
