@@ -19,11 +19,6 @@ volatile Window initialising = None;
 XFontStruct     *font;
 Client          *head_client = NULL;
 Application     *head_app = NULL;
-Atom            xa_wm_state;
-Atom            xa_wm_change_state;
-Atom            xa_wm_protos;
-Atom            xa_wm_delete;
-Atom            xa_wm_cmapwins;
 Cursor          move_curs;
 Cursor          resize_curs;
 const char      *opt_display = "";
@@ -39,14 +34,29 @@ int             vdesk = KEY_TO_VDESK(XK_1);
 #ifdef SNAP
 int             opt_snap = 0;
 #endif
+#ifdef SOLIDDRAG
+int             solid_drag = 1;  /* use solid drag by default */
+#endif
 #ifdef SHAPE
 int             have_shape, shape_event;
 #endif
-Atom            mwm_hints;
 unsigned int numlockmask = 0;
 static unsigned int grabmask1 = ControlMask|Mod1Mask;
 /* This one is used for per-client mousebutton grabs, so global: */
 unsigned int grabmask2 = Mod1Mask;
+unsigned int altmask = ShiftMask;
+
+/* Standard X protocol atoms */
+Atom xa_wm_state;
+Atom xa_wm_protos;
+Atom xa_wm_delete;
+Atom xa_wm_cmapwins;
+/* Motif atoms */
+Atom mwm_hints;
+/* EWMH atoms */
+Atom xa_net_wm_desktop;
+Atom xa_net_wm_state;
+Atom xa_net_wm_state_sticky;
 
 static void setup_display(void);
 static void *xmalloc(size_t size);
@@ -111,9 +121,9 @@ int main(int argc, char *argv[]) {
 					&head_app->width, &head_app->height);
 #ifdef VWM
 		} else if (!strcmp(argv[i], "-v") && i+1<argc) {
-			i++;
-			if (head_app)
-				head_app->vdesk = atoi(argv[i]);
+			int v = atoi(argv[++i]);
+			if (head_app && valid_vdesk(v))
+				head_app->vdesk = v;
 		} else if (!strcmp(argv[i], "-s")) {
 			if (head_app)
 				head_app->sticky = 1;
@@ -124,6 +134,13 @@ int main(int argc, char *argv[]) {
 		} else if (!strcmp(argv[i], "-mask2") && i+1<argc) {
 			i++;
 			grabmask2 = parse_modifiers(argv[i]);
+		} else if (!strcmp(argv[i], "-altmask") && i+1<argc) {
+			i++;
+			altmask = parse_modifiers(argv[i]);
+#ifdef SOLIDDRAG
+		} else if (!strcmp(argv[i], "-nosoliddrag")) {
+			solid_drag = 0;
+#endif
 #ifdef STDIO
 		} else if (!strcmp(argv[i], "-V")) {
 			LOG_INFO("evilwm version " VERSION "\n");
@@ -136,9 +153,13 @@ int main(int argc, char *argv[]) {
 			LOG_INFO(" [-fc fixed]");
 #endif
 			LOG_INFO(" [-bg background] [-bw borderwidth]\n");
-			LOG_INFO("              [-snap num] [-mask1 modifiers] [-mask2 modifiers]");
+			LOG_INFO("              [-mask1 modifiers] [-mask2 modifiers] [-altmask modifiers]\n");
+			LOG_INFO("              [-snap num]");
 #ifdef VWM
-			LOG_INFO("\n              [-app name/class] [-g geometry] [-v vdesk] [-s]");
+			LOG_INFO(" [-app name/class] [-g geometry] [-v vdesk] [-s]");
+#endif
+#ifdef SOLIDDRAG
+			LOG_INFO("\n              [-nosoliddrag]");
 #endif
 			LOG_INFO(" [-V]\n");
 			exit((!strcmp(argv[i], "-h") || !strcmp(argv[i], "--help"))?0:1);
@@ -192,6 +213,9 @@ static void setup_display(void) {
 #endif
 		0
 	};
+	KeySym alt_keys_to_grab[] = {
+		KEY_KILL, KEY_LEFT, KEY_RIGHT, KEY_DOWN, KEY_UP
+	};
 	/* used in scanning windows (XQueryTree) */
 	unsigned int i, j, nwins;
 	Window dw1, dw2, *wins;
@@ -205,14 +229,19 @@ static void setup_display(void) {
 	XSetErrorHandler(handle_xerror);
 	/* XSynchronize(dpy, True); */
 
+	/* Standard X protocol atoms */
 	xa_wm_state = XInternAtom(dpy, "WM_STATE", False);
-	xa_wm_change_state = XInternAtom(dpy, "WM_CHANGE_STATE", False);
 	xa_wm_protos = XInternAtom(dpy, "WM_PROTOCOLS", False);
 	xa_wm_delete = XInternAtom(dpy, "WM_DELETE_WINDOW", False);
 #ifdef COLOURMAP
 	xa_wm_cmapwins = XInternAtom(dpy, "WM_COLORMAP_WINDOWS", False);
 #endif
+	/* Motif atoms */
 	mwm_hints = XInternAtom(dpy, _XA_MWM_HINTS, False);
+	/* EWMH atoms */
+	xa_net_wm_desktop = XInternAtom(dpy, "_NET_WM_DESKTOP", False);
+	xa_net_wm_state = XInternAtom(dpy, "_NET_WM_STATE", False);
+	xa_net_wm_state_sticky = XInternAtom(dpy, "_NET_WM_STATE_STICKY", False);
 
 	font = XLoadQueryFont(dpy, opt_font);
 	if (!font) font = XLoadQueryFont(dpy, DEF_FONT);
@@ -298,7 +327,9 @@ static void setup_display(void) {
 		for (keysym = keys_to_grab; *keysym; keysym++) {
 			grab_keysym(screens[i].root, grabmask1, *keysym);
 		}
-		grab_keysym(screens[i].root, grabmask1 ^ ShiftMask, KEY_KILL);
+		for (keysym = alt_keys_to_grab; *keysym; keysym++) {
+			grab_keysym(screens[i].root, grabmask1 | altmask, *keysym);
+		}
 		grab_keysym(screens[i].root, grabmask2, KEY_NEXT);
 
 		/* scan all the windows on this screen */
