@@ -166,6 +166,7 @@ void make_new_client(Window w, ScreenInfo *s) {
 	else {
 		set_wm_state(c, IconicState);
 	}
+	update_net_wm_desktop(c);
 #endif
 }
 
@@ -177,10 +178,27 @@ void make_new_client(Window w, ScreenInfo *s) {
 static void init_geometry(Client *c) {
 	long size_flags;
 	XWindowAttributes attr;
+#ifdef VWM
+	unsigned long nitems, i;
+	unsigned long *lprop;
+	Atom *aprop;
+#endif
 
 #ifdef VWM
 	c->vdesk = vdesk;
+	if ( (lprop = get_property(c->window, xa_net_wm_desktop, XA_CARDINAL, &nitems)) ) {
+		if (nitems && valid_vdesk(lprop[0]))
+			c->vdesk = lprop[0];
+		XFree(lprop);
+	}
 	remove_sticky(c);
+	if ( (aprop = get_property(c->window, xa_net_wm_state, XA_ATOM, &nitems)) ) {
+		for (i = 0; i < nitems; i++) {
+			if (aprop[i] == xa_net_wm_state_sticky)
+				add_sticky(c);
+		}
+		XFree(aprop);
+	}
 #endif
 
 	/* Get current window attributes */
